@@ -205,7 +205,7 @@ func pullImage(ctx context.Context, targetImage reference.Named, imageStore oras
 	}
 
 	imageDigest := desc.Digest.String()
-	if err := signature.PullSigningInformation(ctx, repo, imageStore, imageDigest); err != nil {
+	if err := signature.DefaultSignaturePuller.PullSigningInformation(ctx, repo, imageStore, imageDigest); err != nil {
 		log.Warnf("error pulling signature: %v", err)
 		// it's not a requirement to have a signature for pulling the image
 		return &desc, nil
@@ -356,7 +356,7 @@ func ExportGadgetImages(ctx context.Context, dstFile string, images ...string) e
 			return fmt.Errorf("copying image to remote repository: %w", err)
 		}
 
-		err = signature.ExportSigningInformation(ctx, ociStore, dstStore, desc)
+		err = signature.DefaultSignatureExporter.ExportSigningInformation(ctx, ociStore, dstStore, desc)
 		if errors.Is(err, errdef.ErrNotFound) {
 			continue
 		}
@@ -781,7 +781,7 @@ func getContentBytesFromDescriptor(ctx context.Context, fetcher content.Fetcher,
 	return bytes, nil
 }
 
-func ensureImage(ctx context.Context, imageStore oras.Target, image string, imgOpts *ImageOptions, pullPolicy string) error {
+func ensureImage(ctx context.Context, imageStore oras.GraphTarget, image string, imgOpts *ImageOptions, pullPolicy string) error {
 	switch pullPolicy {
 	case PullImageAlways:
 		_, err := pullGadgetImageToStore(ctx, imageStore, image, &imgOpts.AuthOptions)
