@@ -39,7 +39,9 @@ import (
 	"github.com/inspektor-gadget/inspektor-gadget/pkg/operators"
 	"github.com/inspektor-gadget/inspektor-gadget/pkg/params"
 	"github.com/inspektor-gadget/inspektor-gadget/pkg/resources"
-	signatureverifier "github.com/inspektor-gadget/inspektor-gadget/pkg/signature-verifier"
+	"github.com/inspektor-gadget/inspektor-gadget/pkg/signature"
+	"github.com/inspektor-gadget/inspektor-gadget/pkg/signature/cosign"
+	"github.com/inspektor-gadget/inspektor-gadget/pkg/signature/notation"
 )
 
 const (
@@ -52,6 +54,8 @@ const (
 	annotate                = "annotate"
 	verifyImage             = "verify-image"
 	publicKeys              = "public-keys"
+	certificates            = "notation-certificates"
+	policyDocument          = "notation-policy-document"
 	allowedGadgets          = "allowed-gadgets"
 )
 
@@ -61,6 +65,7 @@ const (
 
 type ociHandler struct {
 	globalParams *params.Params
+	verifyOpts   oci.VerifyOptions
 }
 
 func New() *ociHandler {
@@ -76,6 +81,31 @@ func (o *ociHandler) Init(params *params.Params) error {
 		return fmt.Errorf("ociHandler already initialized")
 	}
 	o.globalParams = params
+
+	verifyOptions := oci.VerifyOptions{
+		VerifySignature: o.globalParams.Get(verifyImage).AsBool(),
+	}
+
+	if verifyOptions.VerifySignature {
+		verifier, err := signature.NewSignatureVerifier(
+			signature.VerifierOptions{
+				CosignVerifierOpts: cosign.VerifierOptions{
+					PublicKeys: o.globalParams.Get(publicKeys).AsStringSlice(),
+				},
+				NotationVerifierOpts: notation.VerifierOptions{
+					Certificates:   o.globalParams.Get(certificates).AsStringSlice(),
+					PolicyDocument: o.globalParams.Get(policyDocument).AsString(),
+				},
+			},
+		)
+		if err != nil {
+			return fmt.Errorf("creating signature verifier: %w", err)
+		}
+		verifyOptions.Verifier = verifier
+	}
+
+	o.verifyOpts = verifyOptions
+
 	return nil
 }
 
@@ -91,10 +121,22 @@ func (o *ociHandler) GlobalParams() api.Params {
 		{
 			Key:          publicKeys,
 			Title:        "Public keys",
-			Description:  "Public keys used to verify the gadgets",
+			Description:  "Public keys used to verify the gadgets with cosign",
 			DefaultValue: resources.InspektorGadgetPublicKey,
 			TypeHint:     api.TypeStringSlice,
 		},
+		{
+			Key:         certificates,
+			Title:       "Notation certificates",
+			Description: "Certificates used to verify the gadgets with notation",
+			TypeHint:    api.TypeStringSlice,
+		},
+		{
+			Key:         policyDocument,
+			Title:       "Notation policy Document",
+			Description: "Policy Document used to verify the gadgets with notation",
+			TypeHint:    api.TypeString,
+		},
 		{
 			Key:         allowedGadgets,
 			Title:       "Allowed Gadgets",
@@ -341,14 +383,7 @@ func (o *OciHandlerInstance) init(gadgetCtx operators.GadgetContext) error {
 			InsecureRegistries: o.globalParams.Get(insecureRegistriesParam).AsStringSlice(),
 			DisallowPulling:    o.globalParams.Get(disallowPulling).AsBool(),
 		},
-		VerifyOptions: oci.VerifyOptions{
-			VerifyOptions: signatureverifier.VerifyOptions{
-				CosignVerifyOptions: signatureverifier.CosignVerifyOptions{
-					PublicKeys: o.globalParams.Get(publicKeys).AsStringSlice(),
-				},
-			},
-			VerifySignature: o.globalParams.Get(verifyImage).AsBool(),
-		},
+		VerifyOptions: o.ociHandler.verifyOpts,
 		AllowedGadgetsOptions: oci.AllowedGadgetsOptions{
 			AllowedGadgets: o.globalParams.Get(allowedGadgets).AsStringSlice(),
 		},
